# idc-index

```{toctree}
:maxdepth: 2
:hidden:
```

:::{warning}

This package is in its early development stages. Its functionality and API will
change.

Stay tuned for the updates and documentation, and please share your feedback
about it by opening issues at the
[idc-index](https://github.com/ImagingDataCommons/idc-index) repository, or by
starting a discussion in [IDC User forum](https://discourse.canceridc.dev/).

:::

```{include} ../README.md
:start-after: <!-- SPHINX-START -->
```

## Contents

```{toctree}
:maxdepth: 2
:titlesonly:
:caption: API docs

column_descriptions
api/idc_index
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
